const fs = require('fs');
const { colors, typography, spacing } = require('./index');

const variables = Object.assign(
  {},
  colors.colorsVars,
  typography.scaleVars,
  typography.fontFamilies,
  spacing.scaleVars
);

const generate = {
  css() {
    return `:root {
    ${Object.keys(variables).reduce((css, colorName) =>
      `${css}\n\t${`--cirrus-${colorName}`}: ${variables[colorName]};`, '')}
    }`;
  },
  scss() {
    return Object.keys(variables).reduce((css, colorName) =>
    `${css}\n${`$cirrus-${colorName}`}: ${variables[colorName]};`, '');
  },
};

function generateTokensFile(type) {
  return generate[type]();
}

fs.writeFileSync('./index.css', generateTokensFile('css'));
fs.writeFileSync('./index.scss', generateTokensFile('scss'));
